==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Story.pm <==
package WebGUI::i18n::Spanish::Asset_Story;
use utf8;
our $I18N = {
  'Replace image with new image' => {
    'lastUpdated' => '1253672155',
    'message' => 'Reemplazar imagen con nueva imagen'
  },
  'Source' => {
    'lastUpdated' => '1253672183',
    'message' => 'Fuente'
  },
  'ago' => {
    'lastUpdated' => '1253672197',
    'message' => 'atrás'
  },
  'assetName' => {
    'lastUpdated' => '1253672209',
    'message' => 'Noticia'
  },
  'byline' => {
    'lastUpdated' => '1253672318',
    'message' => 'Por'
  },
  'byline help' => {
    'lastUpdated' => '1253672343',
    'message' => '¿A quién se atribuye la autoría de la Noticia?'
  },
  'byline tmplvar' => {
    'lastUpdated' => '1253672374',
    'message' => 'La Atribución de autoría. En otras palabras, ¿quién escribió la noticia?'
  },
  'bylineForm' => {
    'lastUpdated' => '1253672296',
    'message' => 'Elemento de formulario para ingresar la Atribución de la Noticia.'
  },
  'canEdit' => {
    'lastUpdated' => '1253672391',
    'message' => 'Un condicional que indica si el usuario puede editar la Noticia.'
  },
  'cancelButton' => {
    'lastUpdated' => '1253672409',
    'message' => 'Un botón para que el usuario cancel el formulario sin guardar los cambios.'
  },
  'crumb_loop' => {
    'lastUpdated' => '1253672509',
    'message' => 'Un ciclo que contiene el rastro (<em>crumbtrail</em>). El primer elemento es un enlace al Archivo que contiene la Noticia. El último elemento es la Noticia, con título y URL. Si hay tres elementos, el del medio corresponderá al Tópico.'
  },
  'crumb_title' => {
    'lastUpdated' => '1253672519',
    'message' => 'El título de la página en el rastro (<em>crumbtrail</em>).'
  },
  'crumb_url' => {
    'lastUpdated' => '1253672570',
    'message' => 'El URL de la página en el rastro (<em>crumbtrail</em>).'
  },
  'edit template' => {
    'lastUpdated' => '1253672597',
    'message' => 'Plantilla para Editar Noticia'
  },
  'formFooter' => {
    'lastUpdated' => '1253672642',
    'message' => 'El código HTML para terminar el formulario para agregar o editar una Noticia.'
  },
  'formHeader' => {
    'lastUpdated' => '1253672688',
    'message' => 'El código HTML para comenzar el formulario para agregar o editar una Noticia.'
  },
  'formTitle' => {
    'lastUpdated' => '1253672700',
    'message' => 'El título para el formulario.'
  },
  'hasPhoto' => {
    'lastUpdated' => '1253672742',
    'message' => 'Un condicional que indica si la variable <strong>photo</strong> en <strong>photo_loop</strong> tiene una imagen o no.'
  },
  'hasPhotos' => {
    'lastUpdated' => '1253672806',
    'message' => 'Un condicional que indica si la Noticia tiene fotos asociadas.'
  },
  'headline' => {
    'lastUpdated' => '1253672852',
    'message' => 'TItular'
  },
  'headline help' => {
    'lastUpdated' => '1253672877',
    'message' => 'Usualmente igual al título. Si se deja en blanco, el titular será tomado del título.'
  },
  'headline tmplvar' => {
    'lastUpdated' => '1253672918',
    'message' => 'El Titular de la Noticia.'
  },
  'headlineForm' => {
    'lastUpdated' => '1253672978',
    'message' => 'Elemento de formulario empleado para escribir el Titular de la Noticia.'
  },
  'highlight' => {
    'lastUpdated' => '1253673053',
    'message' => 'Un Destacado, sin formato ni HTML adicional.'
  },
  'highlights' => {
    'lastUpdated' => '1253673307',
    'message' => 'Elementos Destacados'
  },
  'highlights help' => {
    'lastUpdated' => '1253673336',
    'message' => 'Items destacados de la Noticia a presentar como lista. Ingrese uno por línea.'
  },
  'highlights tmplvar' => {
    'lastUpdated' => '1253673376',
    'message' => 'Todos los elementos Destacados de la Noticia. Cada Destacado debe separarse con un salto de línea.'
  },
  'highlightsForm' => {
    'lastUpdated' => '1253673401',
    'message' => 'Elemento de formulario para ingresar los Destacados de la Noticia.'
  },
  'highlights_loop' => {
    'lastUpdated' => '1253673630',
    'message' => 'Un ciclo que itera sobre los Destacados de la Noticia.'
  },
  'imageAlt' => {
    'lastUpdated' => '1253673761',
    'message' => 'Texto alterno para la imagen, de manera que aparezca en el ALT del IMG que la desplegará.'
  },
  'imageByline' => {
    'lastUpdated' => '1253673776',
    'message' => 'Atribución de la imagen.'
  },
  'imageCaption' => {
    'lastUpdated' => '1253673787',
    'message' => 'Leyenda para la imagen.'
  },
  'imageLink' => {
    'lastUpdated' => '1253673802',
    'message' => 'El URL al cual enlaza la imagen.'
  },
  'imageTitle' => {
    'lastUpdated' => '1253673827',
    'message' => 'Texto alterno para la imagen, de manera que pueda usarse en el TITLE del IMG que la desplegará.'
  },
  'imageUrl' => {
    'lastUpdated' => '1253673862',
    'message' => 'El URL a la imagen.'
  },
  'imgAltForm' => {
    'lastUpdated' => '1253673899',
    'message' => 'El elemento de formulario para introducir el texto alterno para la imagen, de manera que aparezca en el ALT del IMG que la desplegará.'
  },
  'imgBylineForm' => {
    'lastUpdated' => '1253673957',
    'message' => 'Elemento de formulario para la Atribución de la imagen.'
  },
  'imgCaptionForm' => {
    'lastUpdated' => '1253674026',
    'message' => 'Elemento de formulario para la Leyenda de la imagen.'
  },
  'imgDeleteForm' => {
    'lastUpdated' => '1253674066',
    'message' => 'Un campo para eliminar la imagen, además de los datos relacionados a ella. Este campo no estará presente en el ciclo para agregar imágenes.'
  },
  'imgFilename' => {
    'lastUpdated' => '1253674090',
    'message' => 'El URL a la imagen.'
  },
  'imgThumb' => {
    'lastUpdated' => '1253674102',
    'message' => 'El URL a la miniatura de la imagen.'
  },
  'imgTitleForm' => {
    'lastUpdated' => '1253674126',
    'message' => 'Elemento de formulario para el título de la imagen, para que pueda emplearse en el TITLE del IMG que la desplegará.'
  },
  'imgUrl' => {
    'lastUpdated' => '1253674135',
    'message' => 'El URL de la imagen.'
  },
  'imgUrlForm' => {
    'lastUpdated' => '1253674159',
    'message' => 'Elemento de formulario para ingresar el URL de la imagen. Si está presente, la imagen será desplegada como un enlace a este URL.'
  },
  'keyword' => {
    'lastUpdated' => '1253674172',
    'message' => 'Una Palabra Clave, sin formato alguno.'
  },
  'keyword_url' => {
    'lastUpdated' => '1253674193',
    'message' => 'Un URL para ver todas las Noticias en este Archivo que estén relacionadas con la Palabra Clave.'
  },
  'keywordsForm' => {
    'lastUpdated' => '1253674215',
    'message' => 'Elemento de formulario que permite al usuario ingresar las Palabras Claves para la Noticia.'
  },
  'keywords_loop' => {
    'lastUpdated' => '1253674231',
    'message' => 'Un ciclo que itera sobre las Palabras Claves de la Noticia.'
  },
  'location' => {
    'lastUpdated' => '1253674246',
    'message' => 'Localidad'
  },
  'location help' => {
    'lastUpdated' => '1253674262',
    'message' => '¿Dónde tiene lugar la Noticia?'
  },
  'location tmplvar' => {
    'lastUpdated' => '1253674272',
    'message' => 'La ubicación donde ocurre la Noticia.'
  },
  'locationForm' => {
    'lastUpdated' => '1253674293',
    'message' => 'Elemento de formulario para ingresar la Localidad de la Noticia.'
  },
  'newUploadForm' => {
    'lastUpdated' => '1253674306',
    'message' => 'Elemento de formulario para incorporar una imagen.'
  },
  'photo alt' => {
    'lastUpdated' => '1253674317',
    'message' => 'Texto Alterno para la Foto'
  },
  'photo byline' => {
    'lastUpdated' => '1253674330',
    'message' => 'Atribución de la Foto'
  },
  'photo caption' => {
    'lastUpdated' => '1253674340',
    'message' => 'Leyenda de la Foto'
  },
  'photo delete' => {
    'lastUpdated' => '1253674351',
    'message' => 'Eliminar Foto y Metadatos'
  },
  'photo title' => {
    'lastUpdated' => '1253674364',
    'message' => 'Título Alterno para la Foto'
  },
  'photo tmplvar' => {
    'lastUpdated' => '1253674386',
    'message' => 'El blob JSON para la foto procedente del Activo Noticia.'
  },
  'photo url' => {
    'lastUpdated' => '1253674397',
    'message' => 'URL de la Foto'
  },
  'photoWidth' => {
    'lastUpdated' => '1253709379',
    'message' => 'La anchura de las fotos, establecida en el Archivo de Noticias en el cual está esta Noticia.'
  },
  'photo_form_loop' => {
    'lastUpdated' => '1253674423',
    'message' => 'Un ciclo que itera sobre formas para las fotos que han sido incorporadas, y un formulario en blanco para incorporar nuevas fotos.'
  },
  'photo_loop' => {
    'lastUpdated' => '1253674439',
    'message' => 'Un ciclo que itera sobre las fotos e información relacionada.'
  },
  'save and add another photo' => {
    'lastUpdated' => '1253674456',
    'message' => 'Guardar y Agregar otra Foto'
  },
  'save story' => {
    'lastUpdated' => '1253674465',
    'message' => 'Guardar Noticia'
  },
  'saveAndAddButton' => {
    'lastUpdated' => '1253674495',
    'message' => 'El botón para que el usuario pueda guardar la forma y abrirla nuevamente para editar el formulario o incorporar fotos.'
  },
  'saveButton' => {
    'lastUpdated' => '1253674510',
    'message' => 'El botón para que el usuario guarde el formulario.'
  },
  'singlePhoto' => {
    'lastUpdated' => '1253674530',
    'message' => 'Un condicional que indica si la Noticia tiene exactamente una foto incorporada.'
  },
  'story' => {
    'lastUpdated' => '1253674537',
    'message' => 'Noticia'
  },
  'story asset template variables title' => {
    'lastUpdated' => '1253674548',
    'message' => 'Variables de Plantilla para Noticia'
  },
  'story help' => {
    'lastUpdated' => '1253674558',
    'message' => 'La noticia.'
  },
  'story received' => {
    'lastUpdated' => '1253674592',
    'message' => 'Su Noticia ha sido recibida y está siendo procesada para aparecer en el sitio, donde estará disponible para futuros cambios si fuera necesario. Por favor sea paciente.'
  },
  'story tmplvar' => {
    'lastUpdated' => '1253674611',
    'message' => 'La noticia. Note que puede incluir contenido del Editor Extendido.'
  },
  'storyForm' => {
    'lastUpdated' => '1253674627',
    'message' => 'Formulario para que el usuario ingrese el texto de la Noticia.'
  },
  'subtitle' => {
    'lastUpdated' => '1253674636',
    'message' => 'Subtítulo'
  },
  'subtitle help' => {
    'lastUpdated' => '1253674653',
    'message' => 'Similar al Titular, pero usualmente contiene más información.'
  },
  'subtitle tmplvar' => {
    'lastUpdated' => '1253674665',
    'message' => 'El Subtítulo de la Noticia.'
  },
  'subtitleForm' => {
    'lastUpdated' => '1253674681',
    'message' => 'Elemento de formulario para que el usuario ingrese el Subtítulo de la Noticia.'
  },
  'summaryForm' => {
    'lastUpdated' => '1253674697',
    'message' => 'Elemento de formulario para que el usuario ingrese un Resumen de la Noticia.'
  },
  'titleForm' => {
    'lastUpdated' => '1253674713',
    'message' => 'Elemento de formulario para que el usuario ingrese el Título de la Noticia.'
  },
  'updatedTime' => {
    'lastUpdated' => '1253674745',
    'message' => 'La fecha de última actualización de la Noticia, en un formato similar a "2 hora(s) atrás".'
  },
  'updatedTimeEpoch' => {
    'lastUpdated' => '1253674763',
    'message' => 'La fecha de última actualización de la Noticia, como una época Unix.'
  },
  'view template' => {
    'lastUpdated' => '1253674773',
    'message' => 'Plantilla para Noticia'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Story.pm <==
package WebGUI::i18n::Spanish::Asset_Story;
use utf8;
our $I18N = {
  'Replace image with new image' => {
    'lastUpdated' => '1253672155',
    'message' => 'Reemplazar imagen con nueva imagen'
  },
  'Source' => {
    'lastUpdated' => '1253672183',
    'message' => 'Fuente'
  },
  'ago' => {
    'lastUpdated' => '1253672197',
    'message' => 'atrás'
  },
  'assetName' => {
    'lastUpdated' => '1253672209',
    'message' => 'Noticia'
  },
  'byline' => {
    'lastUpdated' => '1253672318',
    'message' => 'Por'
  },
  'byline help' => {
    'lastUpdated' => '1253672343',
    'message' => '¿A quién se atribuye la autoría de la Noticia?'
  },
  'byline tmplvar' => {
    'lastUpdated' => '1253672374',
    'message' => 'La Atribución de autoría. En otras palabras, ¿quién escribió la noticia?'
  },
  'bylineForm' => {
    'lastUpdated' => '1253672296',
    'message' => 'Elemento de formulario para ingresar la Atribución de la Noticia.'
  },
  'canEdit' => {
    'lastUpdated' => '1253672391',
    'message' => 'Un condicional que indica si el usuario puede editar la Noticia.'
  },
  'cancelButton' => {
    'lastUpdated' => '1253672409',
    'message' => 'Un botón para que el usuario cancel el formulario sin guardar los cambios.'
  },
  'crumb_loop' => {
    'lastUpdated' => '1253672509',
    'message' => 'Un ciclo que contiene el rastro (<em>crumbtrail</em>). El primer elemento es un enlace al Archivo que contiene la Noticia. El último elemento es la Noticia, con título y URL. Si hay tres elementos, el del medio corresponderá al Tópico.'
  },
  'crumb_title' => {
    'lastUpdated' => '1253672519',
    'message' => 'El título de la página en el rastro (<em>crumbtrail</em>).'
  },
  'crumb_url' => {
    'lastUpdated' => '1253672570',
    'message' => 'El URL de la página en el rastro (<em>crumbtrail</em>).'
  },
  'edit template' => {
    'lastUpdated' => '1253672597',
    'message' => 'Plantilla para Editar Noticia'
  },
  'formFooter' => {
    'lastUpdated' => '1253672642',
    'message' => 'El código HTML para terminar el formulario para agregar o editar una Noticia.'
  },
  'formHeader' => {
    'lastUpdated' => '1253672688',
    'message' => 'El código HTML para comenzar el formulario para agregar o editar una Noticia.'
  },
  'formTitle' => {
    'lastUpdated' => '1253672700',
    'message' => 'El título para el formulario.'
  },
  'hasPhoto' => {
    'lastUpdated' => '1253672742',
    'message' => 'Un condicional que indica si la variable <strong>photo</strong> en <strong>photo_loop</strong> tiene una imagen o no.'
  },
  'hasPhotos' => {
    'lastUpdated' => '1253672806',
    'message' => 'Un condicional que indica si la Noticia tiene fotos asociadas.'
  },
  'headline' => {
    'lastUpdated' => '1253672852',
    'message' => 'TItular'
  },
  'headline help' => {
    'lastUpdated' => '1253672877',
    'message' => 'Usualmente igual al título. Si se deja en blanco, el titular será tomado del título.'
  },
  'headline tmplvar' => {
    'lastUpdated' => '1253672918',
    'message' => 'El Titular de la Noticia.'
  },
  'headlineForm' => {
    'lastUpdated' => '1253672978',
    'message' => 'Elemento de formulario empleado para escribir el Titular de la Noticia.'
  },
  'highlight' => {
    'lastUpdated' => '1253673053',
    'message' => 'Un Destacado, sin formato ni HTML adicional.'
  },
  'highlights' => {
    'lastUpdated' => '1253673307',
    'message' => 'Elementos Destacados'
  },
  'highlights help' => {
    'lastUpdated' => '1253673336',
    'message' => 'Items destacados de la Noticia a presentar como lista. Ingrese uno por línea.'
  },
  'highlights tmplvar' => {
    'lastUpdated' => '1253673376',
    'message' => 'Todos los elementos Destacados de la Noticia. Cada Destacado debe separarse con un salto de línea.'
  },
  'highlightsForm' => {
    'lastUpdated' => '1253673401',
    'message' => 'Elemento de formulario para ingresar los Destacados de la Noticia.'
  },
  'highlights_loop' => {
    'lastUpdated' => '1253673630',
    'message' => 'Un ciclo que itera sobre los Destacados de la Noticia.'
  },
  'imageAlt' => {
    'lastUpdated' => '1253673761',
    'message' => 'Texto alterno para la imagen, de manera que aparezca en el ALT del IMG que la desplegará.'
  },
  'imageByline' => {
    'lastUpdated' => '1253673776',
    'message' => 'Atribución de la imagen.'
  },
  'imageCaption' => {
    'lastUpdated' => '1253673787',
    'message' => 'Leyenda para la imagen.'
  },
  'imageLink' => {
    'lastUpdated' => '1253673802',
    'message' => 'El URL al cual enlaza la imagen.'
  },
  'imageTitle' => {
    'lastUpdated' => '1253673827',
    'message' => 'Texto alterno para la imagen, de manera que pueda usarse en el TITLE del IMG que la desplegará.'
  },
  'imageUrl' => {
    'lastUpdated' => '1253673862',
    'message' => 'El URL a la imagen.'
  },
  'imgAltForm' => {
    'lastUpdated' => '1253673899',
    'message' => 'El elemento de formulario para introducir el texto alterno para la imagen, de manera que aparezca en el ALT del IMG que la desplegará.'
  },
  'imgBylineForm' => {
    'lastUpdated' => '1253673957',
    'message' => 'Elemento de formulario para la Atribución de la imagen.'
  },
  'imgCaptionForm' => {
    'lastUpdated' => '1253674026',
    'message' => 'Elemento de formulario para la Leyenda de la imagen.'
  },
  'imgDeleteForm' => {
    'lastUpdated' => '1253674066',
    'message' => 'Un campo para eliminar la imagen, además de los datos relacionados a ella. Este campo no estará presente en el ciclo para agregar imágenes.'
  },
  'imgFilename' => {
    'lastUpdated' => '1253674090',
    'message' => 'El URL a la imagen.'
  },
  'imgRemoteUrlForm' => {
    'lastUpdated' => '1307399527',
    'message' => 'El campo que permite especificar un URL remoto para una Foto.'
  },
  'imgThumb' => {
    'lastUpdated' => '1253674102',
    'message' => 'El URL a la miniatura de la imagen.'
  },
  'imgTitleForm' => {
    'lastUpdated' => '1253674126',
    'message' => 'Elemento de formulario para el título de la imagen, para que pueda emplearse en el TITLE del IMG que la desplegará.'
  },
  'imgUrl' => {
    'lastUpdated' => '1253674135',
    'message' => 'El URL de la imagen.'
  },
  'imgUrlForm' => {
    'lastUpdated' => '1253674159',
    'message' => 'Elemento de formulario para ingresar el URL de la imagen. Si está presente, la imagen será desplegada como un enlace a este URL.'
  },
  'keyword' => {
    'lastUpdated' => '1253674172',
    'message' => 'Una Palabra Clave, sin formato alguno.'
  },
  'keyword_url' => {
    'lastUpdated' => '1253674193',
    'message' => 'Un URL para ver todas las Noticias en este Archivo que estén relacionadas con la Palabra Clave.'
  },
  'keywordsForm' => {
    'lastUpdated' => '1253674215',
    'message' => 'Elemento de formulario que permite al usuario ingresar las Palabras Claves para la Noticia.'
  },
  'keywords_loop' => {
    'lastUpdated' => '1253674231',
    'message' => 'Un ciclo que itera sobre las Palabras Claves de la Noticia.'
  },
  'location' => {
    'lastUpdated' => '1253674246',
    'message' => 'Localidad'
  },
  'location help' => {
    'lastUpdated' => '1253674262',
    'message' => '¿Dónde tiene lugar la Noticia?'
  },
  'location tmplvar' => {
    'lastUpdated' => '1253674272',
    'message' => 'La ubicación donde ocurre la Noticia.'
  },
  'locationForm' => {
    'lastUpdated' => '1253674293',
    'message' => 'Elemento de formulario para ingresar la Localidad de la Noticia.'
  },
  'newUploadForm' => {
    'lastUpdated' => '1253674306',
    'message' => 'Elemento de formulario para incorporar una imagen.'
  },
  'photo alt' => {
    'lastUpdated' => '1253674317',
    'message' => 'Texto Alterno para la Foto'
  },
  'photo byline' => {
    'lastUpdated' => '1253674330',
    'message' => 'Atribución de la Foto'
  },
  'photo caption' => {
    'lastUpdated' => '1253674340',
    'message' => 'Leyenda de la Foto'
  },
  'photo delete' => {
    'lastUpdated' => '1253674351',
    'message' => 'Eliminar Foto y Metadatos'
  },
  'photo remote url' => {
    'lastUpdated' => '1307399544',
    'message' => 'URL Remoto para Foto'
  },
  'photo title' => {
    'lastUpdated' => '1253674364',
    'message' => 'Título Alterno para la Foto'
  },
  'photo tmplvar' => {
    'lastUpdated' => '1253674386',
    'message' => 'El blob JSON para la foto procedente del Activo Noticia.'
  },
  'photo url' => {
    'lastUpdated' => '1253674397',
    'message' => 'URL de la Foto'
  },
  'photoWidth' => {
    'lastUpdated' => '1253709379',
    'message' => 'La anchura de las fotos, establecida en el Archivo de Noticias en el cual está esta Noticia.'
  },
  'photo_form_loop' => {
    'lastUpdated' => '1253674423',
    'message' => 'Un ciclo que itera sobre formas para las fotos que han sido incorporadas, y un formulario en blanco para incorporar nuevas fotos.'
  },
  'photo_loop' => {
    'lastUpdated' => '1253674439',
    'message' => 'Un ciclo que itera sobre las fotos e información relacionada.'
  },
  'save and add another photo' => {
    'lastUpdated' => '1253674456',
    'message' => 'Guardar y Agregar otra Foto'
  },
  'save story' => {
    'lastUpdated' => '1253674465',
    'message' => 'Guardar Noticia'
  },
  'saveAndAddButton' => {
    'lastUpdated' => '1253674495',
    'message' => 'El botón para que el usuario pueda guardar la forma y abrirla nuevamente para editar el formulario o incorporar fotos.'
  },
  'saveButton' => {
    'lastUpdated' => '1253674510',
    'message' => 'El botón para que el usuario guarde el formulario.'
  },
  'singlePhoto' => {
    'lastUpdated' => '1253674530',
    'message' => 'Un condicional que indica si la Noticia tiene exactamente una foto incorporada.'
  },
  'story' => {
    'lastUpdated' => '1253674537',
    'message' => 'Noticia'
  },
  'story asset template variables title' => {
    'lastUpdated' => '1253674548',
    'message' => 'Variables de Plantilla para Noticia'
  },
  'story help' => {
    'lastUpdated' => '1253674558',
    'message' => 'La noticia.'
  },
  'story received' => {
    'lastUpdated' => '1253674592',
    'message' => 'Su Noticia ha sido recibida y está siendo procesada para aparecer en el sitio, donde estará disponible para futuros cambios si fuera necesario. Por favor sea paciente.'
  },
  'story tmplvar' => {
    'lastUpdated' => '1253674611',
    'message' => 'La noticia. Note que puede incluir contenido del Editor Extendido.'
  },
  'storyForm' => {
    'lastUpdated' => '1253674627',
    'message' => 'Formulario para que el usuario ingrese el texto de la Noticia.'
  },
  'subtitle' => {
    'lastUpdated' => '1253674636',
    'message' => 'Subtítulo'
  },
  'subtitle help' => {
    'lastUpdated' => '1253674653',
    'message' => 'Similar al Titular, pero usualmente contiene más información.'
  },
  'subtitle tmplvar' => {
    'lastUpdated' => '1253674665',
    'message' => 'El Subtítulo de la Noticia.'
  },
  'subtitleForm' => {
    'lastUpdated' => '1253674681',
    'message' => 'Elemento de formulario para que el usuario ingrese el Subtítulo de la Noticia.'
  },
  'summaryForm' => {
    'lastUpdated' => '1253674697',
    'message' => 'Elemento de formulario para que el usuario ingrese un Resumen de la Noticia.'
  },
  'titleForm' => {
    'lastUpdated' => '1253674713',
    'message' => 'Elemento de formulario para que el usuario ingrese el Título de la Noticia.'
  },
  'updatedTime' => {
    'lastUpdated' => '1253674745',
    'message' => 'La fecha de última actualización de la Noticia, en un formato similar a "2 hora(s) atrás".'
  },
  'updatedTimeEpoch' => {
    'lastUpdated' => '1253674763',
    'message' => 'La fecha de última actualización de la Noticia, como una época Unix.'
  },
  'view template' => {
    'lastUpdated' => '1253674773',
    'message' => 'Plantilla para Noticia'
  }
}
;

1;
